import * as tslib_1 from "tslib";
import { SetColumn } from '../../model';
import { filterMissingMarkup, findFilterMissing } from '../missing';
import ADialog from './ADialog';
import { forEach } from './utils';
import { cssClass } from '../../styles';
import { isCategoryIncluded } from '../../model/internalCategorical';
/** @internal */
var CategoricalFilterDialog = /** @class */ (function (_super) {
    tslib_1.__extends(CategoricalFilterDialog, _super);
    function CategoricalFilterDialog(column, dialog) {
        var _this = _super.call(this, dialog, {
            livePreview: 'filter'
        }) || this;
        _this.column = column;
        _this.before = _this.column.getFilter() || { filter: '', filterMissing: false };
        return _this;
    }
    CategoricalFilterDialog.prototype.build = function (node) {
        var _this = this;
        node.insertAdjacentHTML('beforeend', "<div class=\"" + cssClass('dialog-table') + "\">\n        <label class=\"" + cssClass('checkbox') + " " + cssClass('dialog-filter-table-entry') + "\">\n          <input type=\"checkbox\" checked>\n          <span>\n            <span class=\"" + cssClass('dialog-filter-table-color') + "\"></span>\n            <div>Un/Select All</div>\n          </span>\n        </label>\n        " + this.column.categories.map(function (c) { return "<label class=\"" + cssClass('checkbox') + " " + cssClass('dialog-filter-table-entry') + "\">\n          <input data-cat=\"" + c.name + "\" type=\"checkbox\"" + (isCategoryIncluded(_this.before, c) ? 'checked' : '') + ">\n          <span>\n            <span class=\"" + cssClass('dialog-filter-table-color') + "\" style=\"background-color: " + c.color + "\"></span>\n            <div>" + c.label + "</div>\n          </span>\n        </label>"; }).join('') + "\n    </div>");
        // selectAll
        var selectAll = this.findInput('input:not([data-cat])');
        selectAll.onchange = function () {
            forEach(node, 'input[data-cat]', function (n) { return n.checked = selectAll.checked; });
        };
        if (this.column instanceof SetColumn) {
            var some = this.before.mode !== 'every';
            node.insertAdjacentHTML('beforeend', "<strong>Show rows where</strong>");
            node.insertAdjacentHTML('beforeend', "<label class=\"" + cssClass('checkbox') + "\">\n        <input type=\"radio\" " + (!some ? 'checked="checked"' : '') + " name=\"mode\" value=\"every\">\n        <span>all are selected</span>\n      </label>");
            node.insertAdjacentHTML('beforeend', "<label class=\"" + cssClass('checkbox') + "\" style=\"padding-bottom: 0.6em\">\n        <input type=\"radio\" " + (some ? 'checked="checked"' : '') + " name=\"mode\" value=\"some\">\n        <span>some are selected</span>\n      </label>");
        }
        node.insertAdjacentHTML('beforeend', filterMissingMarkup(this.before.filterMissing));
        this.enableLivePreviews('input[type=checkbox],input[type=radio]');
    };
    CategoricalFilterDialog.prototype.updateFilter = function (filter, filterMissing, someMode) {
        if (someMode === void 0) { someMode = false; }
        var noFilter = filter == null && filterMissing === false;
        var f = { filter: filter, filterMissing: filterMissing };
        if (this.column instanceof SetColumn) {
            f.mode = someMode ? 'some' : 'every';
        }
        this.column.setFilter(noFilter ? null : f);
    };
    CategoricalFilterDialog.prototype.reset = function () {
        this.forEach('input[data-cat]', function (n) { return n.checked = true; });
        findFilterMissing(this.node).checked = false;
        var mode = this.findInput('input[value=every]');
        if (mode) {
            mode.checked = true;
        }
    };
    CategoricalFilterDialog.prototype.cancel = function () {
        this.updateFilter(this.before.filter === '' ? null : this.before.filter, this.before.filterMissing, this.before.mode === 'some');
    };
    CategoricalFilterDialog.prototype.submit = function () {
        var f = this.forEach('input[data-cat]', function (n) { return n.checked ? n.dataset.cat : ''; }).filter(Boolean);
        if (f.length === this.column.categories.length) { // all checked = no filter
            f = null;
        }
        var filterMissing = findFilterMissing(this.node).checked;
        var mode = this.findInput('input[value=some]');
        this.updateFilter(f, filterMissing, mode != null && mode.checked);
        return true;
    };
    return CategoricalFilterDialog;
}(ADialog));
export default CategoricalFilterDialog;
//# sourceMappingURL=CategoricalFilterDialog.js.map